==> libstpk-0.9.30.0.tar.gz: libstpk-0.9.30.0/demo/BAROVOR/fft_val_define_isp.f90 <==
module fft_val_define_isp

  double precision, allocatable, dimension(:,:) :: zi     ! array of psi

  real, allocatable, dimension(:,:) :: psid   ! array of psi
  real, allocatable, dimension(:,:) :: ud     ! array of u
  real, allocatable, dimension(:,:) :: vd     ! array of v
  real, allocatable, dimension(:,:) :: zd     ! array of zeta
  double precision, allocatable, dimension(:,:) :: tmpr  ! temporary array
  double precision, allocatable, dimension(:,:) :: tmpi  ! temporary array
  double precision, allocatable, dimension(:,:) :: ur    ! array of psi
  double precision, allocatable, dimension(:,:) :: vr    ! array of psi
  double precision, allocatable, dimension(:,:) :: zor    ! array of psi
  double precision, allocatable, dimension(:,:) :: psior  ! array of psi

  complex(kind(0d0)), allocatable, dimension(:,:) :: psiko
  complex(kind(0d0)), allocatable, dimension(:,:) :: zko
  complex(kind(0d0)), allocatable, dimension(:,:) :: psikn
  complex(kind(0d0)), allocatable, dimension(:,:) :: zopt1
  complex(kind(0d0)), allocatable, dimension(:,:) :: uk
  complex(kind(0d0)), allocatable, dimension(:,:) :: vk

!-- For ISPACK

  double precision, allocatable, dimension(:,:) :: zor_isp
  double precision, allocatable, dimension(:,:) :: psior_isp
  double precision, allocatable, dimension(:,:) :: ur_isp
  double precision, allocatable, dimension(:,:) :: vr_isp
  double precision, allocatable, dimension(:,:) :: zko_isp
  double precision, allocatable, dimension(:,:) :: psiko_isp
  double precision, allocatable, dimension(:,:) :: uk_isp
  double precision, allocatable, dimension(:,:) :: vk_isp
  double precision, allocatable, dimension(:,:) :: tmp_work

end module fft_val_define_isp

==> libstpk-0.9.31.0.tar.gz: libstpk-0.9.31.0/demo/BAROVOR/fft_val_define_isp.f90 <==
module fft_val_define_isp

  double precision, allocatable, dimension(:,:) :: zi     ! array of psi

  real, allocatable, dimension(:,:) :: psid   ! array of psi
  real, allocatable, dimension(:,:) :: ud     ! array of u
  real, allocatable, dimension(:,:) :: vd     ! array of v
  real, allocatable, dimension(:,:) :: zd     ! array of zeta
  real, allocatable, dimension(:,:) :: dmp_stretchd
  real, allocatable, dimension(:,:) :: dmp_advectd
  double precision, allocatable, dimension(:,:) :: tmpr  ! temporary array
  double precision, allocatable, dimension(:,:) :: tmpi  ! temporary array
  double precision, allocatable, dimension(:,:) :: ur    ! array of psi
  double precision, allocatable, dimension(:,:) :: vr    ! array of psi
  double precision, allocatable, dimension(:,:) :: zor    ! array of psi
  double precision, allocatable, dimension(:,:) :: psior  ! array of psi
  double precision, allocatable, dimension(:,:) :: dmp_stretchr
  double precision, allocatable, dimension(:,:) :: dmp_advectr

  complex(kind(0d0)), allocatable, dimension(:,:) :: psiko
  complex(kind(0d0)), allocatable, dimension(:,:) :: zko
  complex(kind(0d0)), allocatable, dimension(:,:) :: psikn
  complex(kind(0d0)), allocatable, dimension(:,:) :: zopt1
  complex(kind(0d0)), allocatable, dimension(:,:) :: uk
  complex(kind(0d0)), allocatable, dimension(:,:) :: vk

!-- For ISPACK

  double precision, allocatable, dimension(:,:) :: zor_isp
  double precision, allocatable, dimension(:,:) :: psior_isp
  double precision, allocatable, dimension(:,:) :: ur_isp
  double precision, allocatable, dimension(:,:) :: vr_isp
  double precision, allocatable, dimension(:,:) :: zko_isp
  double precision, allocatable, dimension(:,:) :: psiko_isp
  double precision, allocatable, dimension(:,:) :: uk_isp
  double precision, allocatable, dimension(:,:) :: vk_isp
  double precision, allocatable, dimension(:,:) :: tmp_work
  double precision, allocatable, dimension(:,:) :: dmp_stretchk_isp
  double precision, allocatable, dimension(:,:) :: dmp_stretchr_isp
  double precision, allocatable, dimension(:,:) :: dmp_advectk_isp
  double precision, allocatable, dimension(:,:) :: dmp_advectr_isp

end module fft_val_define_isp
